@triton.jit decorator compiles Python function into a GPU kernel
Image: Lucasbosch, CC BY-SA 3.0, via Wikimedia Commons
@triton.jit decorator compiles Python function into a GPU kernel
a Triton kernel is
Can your phone run faster with a different brain?
tl.load and tl.store do in Triton: read/write tensors from/to GPU global memory
`tl.load` reads tensors from GPU memory; `tl.store` writes tensors to GPU memory
tl.dot does in Triton: block-level matrix multiply using tensor cores
tl.dot performs block-level matrix multiplication using tensor cores in Triton
to write a vector addition kernel in Triton: load blocks, add, store
```
Triton differs from CUDA
Why does a super-fast computer sometimes run slower than a regular one?
Arm architecture family
ARM processors are the most widely used family of instruction set architectures
Swipe through 100 ML concepts daily
Open Pocket Polymath